@@ -80,7 +80,7 @@ class NavParser:
             self.read_file(nmea)
         else:
             self.read_string(nmea)
-        self.most_recent = max(self._points, key=lambda s: self._points[s].get_timestamp())
+        self.most_recent = max(self._points, key=lambda s: self._points[s].get_timestamp(), default=None)
 
 
     @staticmethod
